@@ -3,7 +3,7 @@
 _plugins = [
     "V1",
     "V2",
-    # "V3",
+    "V3",
 ]
 
 from . import base74, level
